@@ -414,7 +414,9 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
     logger.info(f"SRP request form for SRP code {srp_code} called by {request_user}")
 
     # Check if the provided SRP code is valid
-    if AaSrpLink.objects.filter(srp_code=srp_code).exists() is False:
+    try:
+        srp_link = AaSrpLink.objects.get(srp_code=srp_code)
+    except AaSrpLink.DoesNotExist:
         logger.error(
             f"Unable to locate SRP Fleet using SRP code {srp_code} for "
             f"user {request_user}"
@@ -425,185 +427,185 @@ def request_srp(request: WSGIRequest, srp_code: str) -> HttpResponse:
         )
 
         return redirect("aasrp:dashboard")
+    else:
+        # Check if the SRP link is still open
+        if srp_link.srp_status != AaSrpLink.Status.ACTIVE:
+            messages.error(
+                request, _("This SRP link is no longer available for SRP requests.")
+            )
 
-    srp_link = AaSrpLink.objects.get(srp_code=srp_code)
+            return redirect("aasrp:dashboard")
 
-    # Check if the SRP link is still open
-    if srp_link.srp_status != AaSrpLink.Status.ACTIVE:
-        messages.error(
-            request, _("This SRP link is no longer available for SRP requests.")
-        )
+        # If this is a POST request we need to process the form data
+        if request.method == "POST":
+            # Create a form instance and populate it with data from the request
+            form = AaSrpRequestForm(request.POST)
+            form_is_valid = form.is_valid()
 
-        return redirect("aasrp:dashboard")
+            logger.debug(f"Request type POST contains valid form: {form_is_valid}")
 
-    # If this is a POST request we need to process the form data
-    if request.method == "POST":
-        # Create a form instance and populate it with data from the request
-        form = AaSrpRequestForm(request.POST)
-        form_is_valid = form.is_valid()
+            # Check whether it's valid:
+            if form.is_valid():
+                creator = request.user
+                post_time = timezone.now()
+                submitted_killmail_link = form.cleaned_data["killboard_link"]
 
-        logger.debug(f"Request type POST contains valid form: {form_is_valid}")
+                # Parse killmail
+                try:
+                    srp_kill_link = AaSrpManager.get_kill_id(submitted_killmail_link)
 
-        # Check whether it's valid:
-        if form.is_valid():
-            creator = request.user
-            post_time = timezone.now()
-            submitted_killmail_link = form.cleaned_data["killboard_link"]
+                    (ship_type_id, ship_value, victim_id) = AaSrpManager.get_kill_data(
+                        srp_kill_link
+                    )
+                except ValueError:
+                    # Invalid killmail
+                    logger.debug(
+                        f"User {request_user} submitted an invalid killmail link "
+                        f"({submitted_killmail_link}) or zKillboard server could "
+                        "not be reached"
+                    )
 
-            # Parse killmail
-            try:
-                srp_kill_link = AaSrpManager.get_kill_id(submitted_killmail_link)
+                    messages.error(
+                        request,
+                        _(
+                            "Your SRP request Killmail link is invalid. "
+                            f"Please make sure you are using {ZKILLBOARD_BASE_URL}"
+                        ),
+                    )
 
-                (ship_type_id, ship_value, victim_id) = AaSrpManager.get_kill_data(
-                    srp_kill_link
-                )
-            except ValueError:
-                # Invalid killmail
-                logger.debug(
-                    f"User {request_user} submitted an invalid killmail link "
-                    f"({submitted_killmail_link}) or zKillboard server could "
-                    "not be reached"
-                )
+                    return redirect("aasrp:dashboard")
+
+                if request.user.character_ownerships.filter(
+                    character__character_id=str(victim_id)
+                ).exists():
+                    srp_request__character = EveCharacter.objects.get_character_by_id(
+                        victim_id
+                    )
+
+                    (
+                        srp_request__ship,
+                        created_from_esi,
+                    ) = EveType.objects.get_or_create_esi(id=ship_type_id)
+
+                    srp_request = AaSrpRequest(
+                        killboard_link=submitted_killmail_link,
+                        creator=creator,
+                        srp_link=srp_link,
+                        character=srp_request__character,
+                        ship_name=srp_request__ship.name,
+                        ship=srp_request__ship,
+                        loss_amount=ship_value,
+                        post_time=post_time,
+                        request_code=get_random_string(length=16),
+                    )
+                    srp_request.save()
+
+                    # Save Request Create Even in request history
+                    AaSrpRequestComment(
+                        srp_request=srp_request,
+                        comment_type=AaSrpRequestComment.Type.REQUEST_ADDED,
+                        creator=creator,
+                        new_status=AaSrpRequest.Status.PENDING,
+                    ).save()
+
+                    # Add request info to request history
+                    srp_request_additional_info = form.cleaned_data["additional_info"]
+                    AaSrpRequestComment(
+                        comment=srp_request_additional_info,
+                        srp_request=srp_request,
+                        comment_type=AaSrpRequestComment.Type.REQUEST_INFO,
+                        creator=creator,
+                    ).save()
+
+                    # Add insurance information
+                    insurance_information = AaSrpManager.get_insurance_for_ship_type(
+                        ship_type_id=ship_type_id
+                    )
+
+                    for insurance_level in insurance_information["levels"]:
+                        logger.debug(insurance_level)
+
+                        insurance = AaSrpInsurance(
+                            srp_request=srp_request,
+                            insurance_level=insurance_level["name"],
+                            insurance_cost=insurance_level["cost"],
+                            insurance_payout=insurance_level["payout"],
+                        )
+                        insurance.save()
+
+                    user_name = request.user
+                    character_name = srp_request__character
+                    srp_name = srp_link.srp_name
+                    srp_code = srp_request.request_code
+                    logger.info(
+                        f"Created SRP request on behalf of user {user_name} "
+                        f"(character: {character_name}) for fleet name {srp_name} "
+                        f"with SRP code {srp_code}"
+                    )
+
+                    ship = srp_request.ship.name
+                    messages.success(
+                        request, _(f"Submitted SRP request for your {ship}.")
+                    )
+
+                    # Send message to the srp team in their discord channel
+                    if AASRP_SRP_TEAM_DISCORD_CHANNEL is not None:
+                        site_base_url = site_absolute_url()
+                        request_code = srp_request.request_code
+                        character_name = srp_request__character.character_name
+                        ship_type = srp_request__ship.name
+                        zkillboard_link = srp_request.killboard_link
+                        additional_information = srp_request_additional_info.replace(
+                            "@", "{@}"
+                        )
+                        srp_link = site_base_url + reverse(
+                            "aasrp:view_srp_requests", args=[srp_link.srp_code]
+                        )
+
+                        title = "New SRP Request"
+                        message = f"**Request Code:** {request_code}\n"
+                        message += f"**Character:** {character_name}\n"
+                        message += f"**Ship:** {ship_type}\n"
+                        message += f"**zKillboard Link:** {zkillboard_link}\n"
+                        message += (
+                            f"**Additional Information:**\n{additional_information}\n\n"
+                        )
+                        message += f"**SRP Code:** {srp_code}\n"
+                        message += f"**SRP Link:** {srp_link}\n"
+
+                        logger.info(
+                            "Sending SRP request notification to the SRP team channel "
+                            "on Discord"
+                        )
+
+                        send_message_to_discord_channel(
+                            channel_id=AASRP_SRP_TEAM_DISCORD_CHANNEL,
+                            title=title,
+                            message=message,
+                        )
+
+                    return redirect("aasrp:dashboard")
 
                 messages.error(
                     request,
                     _(
-                        "Your SRP request Killmail link is invalid. "
-                        f"Please make sure you are using {ZKILLBOARD_BASE_URL}"
+                        f"Character {victim_id} does not belong to your Auth "
+                        "account. Please add this character as an alt to "
+                        "your main and try again."
                     ),
                 )
 
                 return redirect("aasrp:dashboard")
 
-            if request.user.character_ownerships.filter(
-                character__character_id=str(victim_id)
-            ).exists():
-                srp_request__character = EveCharacter.objects.get_character_by_id(
-                    victim_id
-                )
+        # If a GET (or any other method) we'll create a blank form
+        else:
+            logger.debug(f"Returning blank SRP request form for {request.user}")
 
-                (
-                    srp_request__ship,
-                    created_from_esi,
-                ) = EveType.objects.get_or_create_esi(id=ship_type_id)
+            form = AaSrpRequestForm()
 
-                srp_request = AaSrpRequest(
-                    killboard_link=submitted_killmail_link,
-                    creator=creator,
-                    srp_link=srp_link,
-                    character=srp_request__character,
-                    ship_name=srp_request__ship.name,
-                    ship=srp_request__ship,
-                    loss_amount=ship_value,
-                    post_time=post_time,
-                    request_code=get_random_string(length=16),
-                )
-                srp_request.save()
+        context = {"srp_link": srp_link, "form": form}
 
-                # Save Request Create Even in request history
-                AaSrpRequestComment(
-                    srp_request=srp_request,
-                    comment_type=AaSrpRequestComment.Type.REQUEST_ADDED,
-                    creator=creator,
-                    new_status=AaSrpRequest.Status.PENDING,
-                ).save()
-
-                # Add request info to request history
-                srp_request_additional_info = form.cleaned_data["additional_info"]
-                AaSrpRequestComment(
-                    comment=srp_request_additional_info,
-                    srp_request=srp_request,
-                    comment_type=AaSrpRequestComment.Type.REQUEST_INFO,
-                    creator=creator,
-                ).save()
-
-                # Add insurance information
-                insurance_information = AaSrpManager.get_insurance_for_ship_type(
-                    ship_type_id=ship_type_id
-                )
-
-                for insurance_level in insurance_information["levels"]:
-                    logger.debug(insurance_level)
-
-                    insurance = AaSrpInsurance(
-                        srp_request=srp_request,
-                        insurance_level=insurance_level["name"],
-                        insurance_cost=insurance_level["cost"],
-                        insurance_payout=insurance_level["payout"],
-                    )
-                    insurance.save()
-
-                user_name = request.user
-                character_name = srp_request__character
-                srp_name = srp_link.srp_name
-                srp_code = srp_request.request_code
-                logger.info(
-                    f"Created SRP request on behalf of user {user_name} "
-                    f"(character: {character_name}) for fleet name {srp_name} "
-                    f"with SRP code {srp_code}"
-                )
-
-                ship = srp_request.ship.name
-                messages.success(request, _(f"Submitted SRP request for your {ship}."))
-
-                # Send message to the srp team in their discord channel
-                if AASRP_SRP_TEAM_DISCORD_CHANNEL is not None:
-                    site_base_url = site_absolute_url()
-                    request_code = srp_request.request_code
-                    character_name = srp_request__character.character_name
-                    ship_type = srp_request__ship.name
-                    zkillboard_link = srp_request.killboard_link
-                    additional_information = srp_request_additional_info.replace(
-                        "@", "{@}"
-                    )
-                    srp_link = site_base_url + reverse(
-                        "aasrp:view_srp_requests", args=[srp_link.srp_code]
-                    )
-
-                    title = "New SRP Request"
-                    message = f"**Request Code:** {request_code}\n"
-                    message += f"**Character:** {character_name}\n"
-                    message += f"**Ship:** {ship_type}\n"
-                    message += f"**zKillboard Link:** {zkillboard_link}\n"
-                    message += (
-                        f"**Additional Information:**\n{additional_information}\n\n"
-                    )
-                    message += f"**SRP Code:** {srp_code}\n"
-                    message += f"**SRP Link:** {srp_link}\n"
-
-                    logger.info(
-                        "Sending SRP request notification to the SRP team channel on "
-                        "Discord"
-                    )
-
-                    send_message_to_discord_channel(
-                        channel_id=AASRP_SRP_TEAM_DISCORD_CHANNEL,
-                        title=title,
-                        message=message,
-                    )
-
-                return redirect("aasrp:dashboard")
-
-            messages.error(
-                request,
-                _(
-                    f"Character {victim_id} does not belong to your Auth "
-                    "account. Please add this character as an alt to "
-                    "your main and try again."
-                ),
-            )
-
-            return redirect("aasrp:dashboard")
-
-    # If a GET (or any other method) we'll create a blank form
-    else:
-        logger.debug(f"Returning blank SRP request form for {request.user}")
-
-        form = AaSrpRequestForm()
-
-    context = {"srp_code": srp_code, "form": form}
-
-    return render(request, "aasrp/request_srp.html", context)
+        return render(request, "aasrp/request_srp.html", context)
 
 
 @login_required
@@ -855,7 +857,7 @@ def delete_srp_link(request: WSGIRequest, srp_code: str):
 
 
 @login_required
-@permissions_required(("aasrp.manage_srp", "aasrp.manage_srp_requests"))
+@permission_required("aasrp.basic_access")
 def ajax_srp_request_additional_information(
     request: WSGIRequest, srp_code: str, srp_request_code: str
 ) -> HttpResponse:
